SqfliteSqlCommand class abstract

Sql command. internal only.

Available extensions

Constructors

SqfliteSqlCommand.delete(String table, {String? where, List<Object?>? whereArgs})
Delete factory.
factory
SqfliteSqlCommand.execute(String sql, [List<Object?>? arguments])
Execute command.
factory
SqfliteSqlCommand.insert(String table, Map<String, Object?> values, {String? nullColumnHack, ConflictAlgorithm? conflictAlgorithm})
Insert factory.
factory
SqfliteSqlCommand.query(String table, {bool? distinct, List<String>? columns, String? where, List<Object?>? whereArgs, String? groupBy, String? having, String? orderBy, int? limit, int? offset})
Query factory.
factory
SqfliteSqlCommand.raw(SqliteSqlCommandType type, String sql, [List<Object?>? arguments])
Sql command.
factory
SqfliteSqlCommand.rawDelete(String sql, [List<Object?>? arguments])
Delete command.
factory
SqfliteSqlCommand.rawInsert(String sql, [List<Object?>? arguments])
Insert command.
factory
SqfliteSqlCommand.rawQuery(String sql, [List<Object?>? arguments])
Query command.
factory
SqfliteSqlCommand.rawUpdate(String sql, [List<Object?>? arguments])
Update command.
factory
SqfliteSqlCommand.update(String table, Map<String, Object?> values, {String? where, List<Object?>? whereArgs, ConflictAlgorithm? conflictAlgorithm})
Update factory.
factory

Properties

arguments List<Object?>?
The sql arguments.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sql String
The sql statement.
no setter
type SqliteSqlCommandType
The command type.
no setter

Methods

delete(DatabaseExecutor executor) Future<int>

Available on SqfliteSqlCommand, provided by the SqfliteSqlCommandExecutorExt extension

Execute the command as a delete.
execute(DatabaseExecutor executor) Future<void>

Available on SqfliteSqlCommand, provided by the SqfliteSqlCommandExecutorExt extension

Execute the command.
insert(DatabaseExecutor executor) Future<int>

Available on SqfliteSqlCommand, provided by the SqfliteSqlCommandExecutorExt extension

Execute the command as an insert.
iterate(DatabaseExecutor executor, {int? bufferSize, required SqfliteCursorRowCallback onRow}) Future<void>

Available on SqfliteSqlCommand, provided by the SqfliteSqlCommandExecutorExt extension

Execute the command as an iterative query.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
query(DatabaseExecutor executor) Future<List<Map<String, Object?>>>

Available on SqfliteSqlCommand, provided by the SqfliteSqlCommandExecutorExt extension

Execute the command as a query.
queryIterate(DatabaseExecutor executor, {int? bufferSize, required SqfliteCursorRowCallback onRow}) Future<void>

Available on SqfliteSqlCommand, provided by the SqfliteSqlCommandExecutorExt extension

Execute the command as an iterative query.
toString() String
A string representation of this object.
inherited
update(DatabaseExecutor executor) Future<int>

Available on SqfliteSqlCommand, provided by the SqfliteSqlCommandExecutorExt extension

Execute the command as an update.

Operators

operator ==(Object other) bool
The equality operator.
inherited